"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetaErrorFactory = void 0;
const UnauthorizedError_1 = require("./UnauthorizedError");
const RateLimitExceededError_1 = require("./RateLimitExceededError");
const InternalServerError_1 = require("./InternalServerError");
const GenericError_1 = require("./GenericError");
/**
 * MetaErrorFactory class responsible for generating and throwing specific errors based on the HTTP status code.
 */
class MetaErrorFactory {
    /**
     * Handles HTTP errors and throws the appropriate exception.
     * @param statusCode - The HTTP status code from the API response.
     * @param errorMessage - Optional error message for further details.
     * @throws Throws an error corresponding to the provided status code.
     */
    static throwRequestErrorAPI(statusCode, errorMessage) {
        switch (statusCode) {
            case 401:
                throw new UnauthorizedError_1.UnauthorizedError(errorMessage);
            case 429:
                throw new RateLimitExceededError_1.RateLimitExceededError(errorMessage);
            case 500:
                throw new InternalServerError_1.InternalServerError(errorMessage);
            default:
                throw new GenericError_1.GenericError(errorMessage);
        }
    }
}
exports.MetaErrorFactory = MetaErrorFactory;
//# sourceMappingURL=MetaErrorFactory.js.map