"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HelperApiClient = void 0;
const AccessTokenNotSetError_1 = require("../errors/AccessTokenNotSetError");
/**
 * HelperApiClient class to provider assets MetaApiClient.
 * Handles manage token, format data, and error management.
 */
class HelperApiClient {
    /**
     * Method to set access config to request Meta API
     * @param {string} tokenProvider - Optional parameters to set access token
     */
    static setAccessToken(tokenProvider) {
        const accessToken = tokenProvider || process.env.META_ACCESS_TOKEN || "";
        if (!accessToken) {
            throw new AccessTokenNotSetError_1.AccessTokenNotSetError();
        }
        return accessToken;
    }
    /**
     * Method to set api client config
     * @param {ApiClientConfig} config object config api client
     */
    static setApiClientConfig(config) {
        return config || {
            auth: {
                useAccessToken: true,
                clientId: process.env.META_APP_ID,
                clientSecret: process.env.META_APP_SECRET,
            }
        };
    }
    /**
     * Method to set request params to request Meta API
     * @param {URL} url object URL to url request service
     * @param {Record<string, any>} params object request params meta API
     * @param {ApiClientConfig} config object config set params
     */
    static setRequestParams(url, params = {}, config) {
        if (config.useAccessToken) {
            url.searchParams.set('access_token', params === null || params === void 0 ? void 0 : params.accessToken);
        }
        Object.keys(params).forEach(key => url.searchParams.set(key, params[key]));
        return url;
    }
}
exports.HelperApiClient = HelperApiClient;
//# sourceMappingURL=HelperApiClient.js.map